@@ -13,7 +13,7 @@ from .ReParse import Parse  # 正则相关
 
 from .run_on_time import RunOnTime  # 指定时间运行程序
 
-from .queue import RabbitProducer, RabbitConsumer  # 消息队列，生产者和消费者
+from .queue_main import RabbitProducer, RabbitConsumer  # 消息队列，生产者和消费者
 from .queue2 import RabbitConsumer2  # 消息队列，消费者
 
 # 数据库操作相关
