@@ -162,8 +162,9 @@ class Log(object):
 
 
 log = Log()
-
+from functools import wraps
 def catch_error_log(func):
+    @wraps(func)
     def try_catch(*args, **kwargs):
         try:
             return func(*args, **kwargs)
