@@ -56,6 +56,10 @@ class EsOp(object):
     def get_es_info(self):
         return self.conn.info()
 
+    # 解决es写入立刻查找查询不到的问题
+    def refresh_index(self, index=None, **kwargs):
+        self.conn.indices.refresh(index=index, **kwargs)
+
     def get_indices_info(self):
         return self.conn.cat.indices(format='json')
 
